==> cejs-4.5.1.tgz: package/application/locale/resources/kn-IN.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Loading...": "\u0ca4\u0cc1\u0c82\u0cac\u0cbf\u0cb8\u0cb2\u0cbe\u0c97\u0cc1\u0ca4\u0ccd\u0ca4\u0cbf\u0ca6\u0cc6....",
	"Contents": "\u0caa\u0cb0\u0cbf\u0cb5\u0cbf\u0ca1\u0cbf",
	"number": "\u0cb8\u0c82\u0c96\u0ccd\u0caf\u0cc6",
	"log-type-error": "\u0ca6\u0ccb\u0cb7",
	"log-type-info": "\u0cae\u0cbe\u0cb9\u0cbf\u0ca4\u0cbf",
	"log-type-log": "\u0ca6\u0cbe\u0c96\u0cb2\u0cc6",
	"Language": "\u0cad\u0cbe\u0cb7\u0cc6",
	"%1 Y %2 M": "%1 \u0cb5 %2 \u0ca4\u0cbf\u0c82",
	"%1 Y": "%1 \u0cb5",
	"%1 M": "%1 \u0ca4\u0cbf\u0c82",
	"%1 ms": "%1 \u0cae\u0cbf.\u0cb8\u0cc6",
	"%1 s": "%1 \u0cb8\u0cc6",
	"%1 min": "%1 \u0ca8\u0cbf",
	"%1 hr": "%1 \u0c97\u0c82",
	"%1 d": "%1 \u0ca6\u0cbf",
	"now": "\u0c88\u0c97",
	"several seconds ago": "\u0cb9\u0cb2\u0cb5\u0cc1 \u0cb8\u0cc6\u0c95\u0cc6\u0c82\u0ca1\u0cc1\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"soon": "\u0cb8\u0ca6\u0ccd\u0caf\u0ca6\u0cb2\u0ccd\u0cb2\u0cc7",
	"%1 seconds ago": "%1 \u0cb8\u0cc6\u0c95\u0cc6\u0c82\u0ca1\u0cc1\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 seconds later": "%1 \u0cb8\u0cc6\u0c95\u0cc6\u0c82\u0ca1\u0cc1\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"%1 minutes ago": "%1 \u0ca8\u0cbf\u0cae\u0cbf\u0cb7\u0ca6 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 minutes later": "%1 \u0ca8\u0cbf\u0cae\u0cbf\u0cb7\u0ca6 \u0ca8\u0c82\u0ca4\u0cb0",
	"%1 hours ago": "%1 \u0c97\u0c82\u0c9f\u0cc6\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 hours later": "%1 \u0c97\u0c82\u0c9f\u0cc6\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"2 days before yesterday, %H:%M": "\u0c85\u0c9a\u0ccd\u0c9a\u0cc6 \u0cae\u0cca\u0ca8\u0ccd\u0ca8\u0cc6, %H:%M",
	"the day before yesterday, %H:%M": "\u0cae\u0cca\u0ca8\u0ccd\u0ca8\u0cc6, %H:%M",
	"yesterday, %H:%M": "\u0ca8\u0cbf\u0ca8\u0ccd\u0ca8\u0cc6, %H:%M",
	"today, %H:%M": "\u0c87\u0c82\u0ca6\u0cc1, %H:%M",
	"tomorrow, %H:%M": "\u0ca8\u0cbe\u0cb3\u0cc6, %H:%M",
	"the day after tomorrow, %H:%M": "\u0ca8\u0cbe\u0ca1\u0cbf\u0ca6\u0ccd\u0ca6\u0cc1, %H:%M",
	"2 days after tomorrow, %H:%M": "\u0c85\u0c9a\u0ccd\u0c9a\u0cc6 \u0ca8\u0cbe\u0ca1\u0cbf\u0ca6\u0ccd\u0ca6\u0cc1, %H:%M",
	"%1 days ago": "%1 \u0ca6\u0cbf\u0ca8\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 days later": "%1 \u0ca6\u0cbf\u0ca8\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"%1 weeks ago": "%1 \u0cb5\u0cbe\u0cb0\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 weeks later": "%1 \u0cb5\u0cbe\u0cb0\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"\u4e2d\u570b": "\u0c9a\u0cc0\u0ca8\u0cbe",
	"\u65e5\u672c": "\u0c9c\u0caa\u0cbe\u0ca8\u0ccd",
	"\ud55c\uad6d": "\u0c95\u0cca\u0cb0\u0cbf\u0caf\u0cbe",
	"Vi\u1ec7t Nam": "\u0cb5\u0cbf\u0caf\u0cc6\u0c9f\u0ccd\u0ca8\u0cbe\u0c82",
	"\u0e44\u0e17\u0e22": "\u0ca5\u0cc8\u0cb2\u0ccd\u0caf\u0cbe\u0c82\u0ca1\u0ccd",
	"India": "\u0cad\u0cbe\u0cb0\u0ca4",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "\u0cae\u0ccd\u0caf\u0cbe\u0ca8\u0ccd\u0cae\u0cbe\u0cb0\u0ccd",
	"Maya": "\u0cae\u0cbe\u0caf\u0cbe",
	"Babylon": "\u0cac\u0ccd\u0caf\u0cbe\u0cac\u0cbf\u0cb2\u0cbe\u0ca8\u0ccd",
	"Persia": "\u0caa\u0cb0\u0ccd\u0cb7\u0cbf\u0caf\u0cbe",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "\u0cb8\u0ccd\u0caa\u0cbe\u0cb0\u0ccd\u0c9f\u0cbe",
	"\u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1": "\u0cae\u0ccd\u0caf\u0cbe\u0cb8\u0cbf\u0ca1\u0cbe\u0ca8\u0ccd",
	"\u03a3\u03b5\u03bb\u03b5\u03c5\u03ba\u03b9\u03b4\u03ce\u03bd": "\u0cb8\u0cc6\u0cb2\u0ccd\u0caf\u0cc2\u0cb8\u0cbf\u0ca6\u0ccd",
	"\u6e2c\u8a66\u7bc4\u4f8b": "\u0c89\u0ca6\u0cbe\u0cb9\u0cb0\u0ca3\u0cc6",
	"\u5171\u6709 %1 \u500b\u6642\u6bb5\u7d00\u9304": "%1 \u0ca6\u0cbe\u0c96\u0cb2\u0cc6\u0c97\u0cb3\u0cc1",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5\u7d00\u9304": "%1 \u0cb5\u0cb0\u0ccd\u0cb7\u0c97\u0cb3\u0cc1",
	"%1/%2/%3": "%1/%2/%3",
	"%1 BCE": "%1 \u0c95\u0ccd\u0cb0\u0cbf.\u0caa\u0cc2",
	"%1 CE": "%1 \u0c95\u0ccd\u0cb0\u0cbf.\u0cb6",
	"\u7236\u89aa": "\u0ca4\u0c82\u0ca6\u0cc6",
	"\u6bcd\u89aa": "\u0ca4\u0cbe\u0caf\u0cbf",
	"\u5206\u985e": "\u0c97\u0cc1\u0c82\u0caa\u0cc1",
	"solar eclipse": "\u0cb8\u0cc2\u0cb0\u0ccd\u0caf \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"lunar eclipse": "\u0c9a\u0c82\u0ca6\u0ccd\u0cb0 \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"total solar eclipse": "\u0caa\u0cc2\u0cb0\u0ccd\u0ca3 \u0cb8\u0cc2\u0cb0\u0ccd\u0caf \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"total lunar eclipse": "\u0caa\u0cc2\u0cb0\u0ccd\u0ca3 \u0c9a\u0c82\u0ca6\u0ccd\u0cb0 \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"\u6714": "\u0c85\u0cae\u0cbe\u0cb5\u0cbe\u0cb8\u0ccd\u0caf\u0cc6",
	"\u671b": "\u0cb9\u0cc1\u0ca3\u0ccd\u0ca3\u0cbf\u0cae\u0cc6",
	"sunrise": "\u0cb8\u0cc2\u0cb0\u0ccd\u0caf\u0ccb\u0ca6\u0caf",
	"moonrise": "\u0c9a\u0c82\u0ca6\u0ccd\u0cb0\u0ccb\u0ca6\u0caf",
	"sunset": "\u0cb8\u0cc2\u0cb0\u0ccd\u0caf\u0cbe\u0cb8\u0ccd\u0ca4",
	"moonset": "\u0c9a\u0c82\u0ca6\u0ccd\u0cb0\u0cbe\u0cb8\u0ccd\u0ca4",
	"zodiac sign": "\u0cb0\u0cbe\u0cb6\u0cbf \u0c9a\u0cbf\u0cb9\u0ccd\u0ca8\u0cc6",
	"Aries": "\u0cae\u0cc7\u0cb7",
	"Taurus": "\u0cb5\u0cc3\u0cb7\u0cad",
	"Gemini": "\u0cae\u0cbf\u0ca5\u0cc1\u0ca8",
	"Cancer": "\u0c95\u0cb0\u0ccd\u0c95\u0cbe\u0c9f\u0c95",
	"Leo": "\u0cb8\u0cbf\u0c82\u0cb9",
	"Virgo": "\u0c95\u0ca8\u0ccd\u0caf\u0cbe",
	"Libra": "\u0ca4\u0cc1\u0cb2\u0cbe",
	"Scorpio": "\u0cb5\u0cc3\u0cb6\u0ccd\u0c9a\u0cbf\u0c95",
	"Sagittarius": "\u0ca7\u0ca8\u0cc1\u0cb8\u0ccd\u0cb8\u0cc1",
	"Capricorn": "\u0cae\u0c95\u0cb0",
	"Aquarius": "\u0c95\u0cc1\u0c82\u0cad",
	"Pisces": "\u0cae\u0cc0\u0ca8",
	"Italy": "\u0c87\u0c9f\u0cb2\u0cbf",
	"Spain": "\u0cb8\u0ccd\u0caa\u0cc7\u0ca8\u0ccd",
	"Portugal": "\u0caa\u0ccb\u0cb0\u0ccd\u0c9a\u0cc1\u0c97\u0cb2\u0ccd",
	"Poland": "\u0caa\u0ccb\u0cb2\u0cc6\u0c82\u0ca1\u0ccd",
	"France": "\u0cab\u0ccd\u0cb0\u0cbe\u0ca8\u0ccd\u0cb8\u0ccd",
	"Luxembourg": "\u0cb2\u0c95\u0ccd\u0cb8\u0cc6\u0c82\u0cac\u0cb0\u0ccd\u0c97\u0ccd",
	"Netherlands": "\u0ca8\u0cc6\u0ca6\u0cb0\u0ccd\u0cb2\u0cc6\u0c82\u0ca1\u0ccd",
	"Bavaria": "\u0cac\u0cb5\u0cc7\u0cb0\u0cbf\u0caf\u0cbe",
	"Austria": "\u0c86\u0cb8\u0ccd\u0c9f\u0ccd\u0cb0\u0cbf\u0caf\u0cbe",
	"Switzerland": "\u0cb8\u0ccd\u0cb5\u0cbf\u0c9c\u0cb0\u0ccd\u0cb2\u0cc6\u0c82\u0ca1\u0ccd",
	"Hungary": "\u0cb9\u0c82\u0c97\u0cc6\u0cb0\u0cbf",
	"Germany": "\u0c9c\u0cb0\u0ccd\u0cae\u0ca8\u0cbf",
	"Norway": "\u0ca8\u0cbe\u0cb0\u0ccd\u0cb5\u0cc6",
	"Denmark": "\u0ca1\u0cc6\u0ca8\u0ccd\u0cae\u0cbe\u0cb0\u0ccd\u0c95\u0ccd",
	"Great Britain": "\u0c97\u0ccd\u0cb0\u0cc7\u0c9f\u0ccd \u0cac\u0ccd\u0cb0\u0cbf\u0c9f\u0ca8\u0ccd",
	"British": "\u0cac\u0ccd\u0cb0\u0cbf\u0c9f\u0cbf\u0cb7\u0ccd",
	"Sweden": "\u0cb8\u0ccd\u0cb5\u0cc0\u0ca1\u0ca8\u0ccd",
	"Finland": "\u0cab\u0cbf\u0ca8\u0ccd\u0cb2\u0ccd\u0caf\u0cbe\u0c82\u0ca1\u0ccd",
	"Bulgaria": "\u0cac\u0cb2\u0ccd\u0c97\u0cc7\u0cb0\u0cbf\u0caf\u0cbe",
	"Soviet Union": "\u0cb8\u0ccb\u0cb5\u0cbf\u0caf\u0ca4\u0ccd \u0c92\u0c95\u0ccd\u0c95\u0cc2\u0c9f",
	"Serbia": "\u0cb8\u0cb0\u0ccd\u0cac\u0cbf\u0caf\u0cbe",
	"Romania": "\u0cb0\u0cca\u0cae\u0cbe\u0ca8\u0cbf\u0caf",
	"Greece": "\u0c97\u0ccd\u0cb0\u0cc0\u0cb8\u0ccd",
	"Turkey": "\u0c9f\u0cb0\u0ccd\u0c95\u0cbf",
	"Egypt": "\u0c88\u0c9c\u0cbf\u0caa\u0ccd\u0c9f\u0ccd",
	"\u5171\u5b58\u7d00\u5e74": "\u0cb8\u0cae\u0c95\u0cbe\u0cb2\u0cc0\u0ca8 \u0c85\u0cb5\u0ca7\u0cbf",
	"\u540c\u570b\u5171\u5b58\u7d00\u5e74": "\u0cb8\u0cae\u0c95\u0cbe\u0cb2\u0cc0\u0ca8 \u0c85\u0cb5\u0ca7\u0cbf (\u0c85\u0ca6\u0cc7 \u0ca6\u0cc7\u0cb6)",
	"\u6240\u6709\u570b\u5bb6": "\u0c8e\u0cb2\u0ccd\u0cb2\u0cbe \u0ca6\u0cc7\u0cb6\u0c97\u0cb3\u0cc1",
	"\u6642\u5340\uff1a": "\u0cb8\u0cae\u0caf \u0cb5\u0cb2\u0caf:",
	"\u81fa\u7063\u5730\u9707": "\u0ca4\u0cc8\u0cb5\u0cbe\u0ca8\u0ccd \u0cad\u0cc2\u0c95\u0c82\u0caa\u0c97\u0cb3\u0cc1",
	"untranslated message count": "939"
},
"kn-IN");

==> cejs-4.5.2.tgz: package/application/locale/resources/kn-IN.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"\u6642\u5340\uff1a": "\u0cb8\u0cae\u0caf \u0cb5\u0cb2\u0caf:",
	"\u81fa\u7063\u5730\u9707": "\u0ca4\u0cc8\u0cb5\u0cbe\u0ca8\u0ccd \u0cad\u0cc2\u0c95\u0c82\u0caa\u0c97\u0cb3\u0cc1",
	"Loading...": "\u0ca4\u0cc1\u0c82\u0cac\u0cbf\u0cb8\u0cb2\u0cbe\u0c97\u0cc1\u0ca4\u0ccd\u0ca4\u0cbf\u0ca6\u0cc6....",
	"\u6240\u6709\u570b\u5bb6": "\u0c8e\u0cb2\u0ccd\u0cb2\u0cbe \u0ca6\u0cc7\u0cb6\u0c97\u0cb3\u0cc1",
	"\u5171\u5b58\u7d00\u5e74": "\u0cb8\u0cae\u0c95\u0cbe\u0cb2\u0cc0\u0ca8 \u0c85\u0cb5\u0ca7\u0cbf",
	"\u6e2c\u8a66\u7bc4\u4f8b": "\u0c89\u0ca6\u0cbe\u0cb9\u0cb0\u0ca3\u0cc6",
	"Vi\u1ec7t Nam": "\u0cb5\u0cbf\u0caf\u0cc6\u0c9f\u0ccd\u0ca8\u0cbe\u0c82",
	"France": "\u0cab\u0ccd\u0cb0\u0cbe\u0ca8\u0ccd\u0cb8\u0ccd",
	"Great Britain": "\u0c97\u0ccd\u0cb0\u0cc7\u0c9f\u0ccd \u0cac\u0ccd\u0cb0\u0cbf\u0c9f\u0ca8\u0ccd",
	"Spain": "\u0cb8\u0ccd\u0caa\u0cc7\u0ca8\u0ccd",
	"\u7236\u89aa": "\u0ca4\u0c82\u0ca6\u0cc6",
	"\u6bcd\u89aa": "\u0ca4\u0cbe\u0caf\u0cbf",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "\u0cae\u0ccd\u0caf\u0cbe\u0ca8\u0ccd\u0cae\u0cbe\u0cb0\u0ccd",
	"Aries": "\u0cae\u0cc7\u0cb7",
	"Taurus": "\u0cb5\u0cc3\u0cb7\u0cad",
	"Gemini": "\u0cae\u0cbf\u0ca5\u0cc1\u0ca8",
	"Cancer": "\u0c95\u0cb0\u0ccd\u0c95\u0cbe\u0c9f\u0c95",
	"Leo": "\u0cb8\u0cbf\u0c82\u0cb9",
	"Virgo": "\u0c95\u0ca8\u0ccd\u0caf\u0cbe",
	"Libra": "\u0ca4\u0cc1\u0cb2\u0cbe",
	"Scorpio": "\u0cb5\u0cc3\u0cb6\u0ccd\u0c9a\u0cbf\u0c95",
	"Sagittarius": "\u0ca7\u0ca8\u0cc1\u0cb8\u0ccd\u0cb8\u0cc1",
	"Capricorn": "\u0cae\u0c95\u0cb0",
	"Aquarius": "\u0c95\u0cc1\u0c82\u0cad",
	"Pisces": "\u0cae\u0cc0\u0ca8",
	"\u540c\u570b\u5171\u5b58\u7d00\u5e74": "\u0cb8\u0cae\u0c95\u0cbe\u0cb2\u0cc0\u0ca8 \u0c85\u0cb5\u0ca7\u0cbf (\u0c85\u0ca6\u0cc7 \u0ca6\u0cc7\u0cb6)",
	"\u6714": "\u0c85\u0cae\u0cbe\u0cb5\u0cbe\u0cb8\u0ccd\u0caf\u0cc6",
	"\u5206\u985e": "\u0c97\u0cc1\u0c82\u0caa\u0cc1",
	"\u4e2d\u570b": "\u0c9a\u0cc0\u0ca8\u0cbe",
	"zodiac sign": "\u0cb0\u0cbe\u0cb6\u0cbf \u0c9a\u0cbf\u0cb9\u0ccd\u0ca8\u0cc6",
	"%1/%2/%3": "%1/%2/%3",
	"%1 BCE": "%1 \u0c95\u0ccd\u0cb0\u0cbf.\u0caa\u0cc2",
	"%1 CE": "%1 \u0c95\u0ccd\u0cb0\u0cbf.\u0cb6",
	"\u5171\u6709 %1 \u500b\u6642\u6bb5\u7d00\u9304": "%1 \u0ca6\u0cbe\u0c96\u0cb2\u0cc6\u0c97\u0cb3\u0cc1",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5\u7d00\u9304": "%1 \u0cb5\u0cb0\u0ccd\u0cb7\u0c97\u0cb3\u0cc1",
	"\u671b": "\u0cb9\u0cc1\u0ca3\u0ccd\u0ca3\u0cbf\u0cae\u0cc6",
	"total lunar eclipse": "\u0caa\u0cc2\u0cb0\u0ccd\u0ca3 \u0c9a\u0c82\u0ca6\u0ccd\u0cb0 \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"total solar eclipse": "\u0caa\u0cc2\u0cb0\u0ccd\u0ca3 \u0cb8\u0cc2\u0cb0\u0ccd\u0caf \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"lunar eclipse": "\u0c9a\u0c82\u0ca6\u0ccd\u0cb0 \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"solar eclipse": "\u0cb8\u0cc2\u0cb0\u0ccd\u0caf \u0c97\u0ccd\u0cb0\u0cb9\u0ca3",
	"moonrise": "\u0c9a\u0c82\u0ca6\u0ccd\u0cb0\u0ccb\u0ca6\u0caf",
	"sunrise": "\u0cb8\u0cc2\u0cb0\u0ccd\u0caf\u0ccb\u0ca6\u0caf",
	"moonset": "\u0c9a\u0c82\u0ca6\u0ccd\u0cb0\u0cbe\u0cb8\u0ccd\u0ca4",
	"sunset": "\u0cb8\u0cc2\u0cb0\u0ccd\u0caf\u0cbe\u0cb8\u0ccd\u0ca4",
	"log-type-error": "\u0ca6\u0ccb\u0cb7",
	"log-type-info": "\u0cae\u0cbe\u0cb9\u0cbf\u0ca4\u0cbf",
	"log-type-log": "\u0ca6\u0cbe\u0c96\u0cb2\u0cc6",
	"Language": "\u0cad\u0cbe\u0cb7\u0cc6",
	"number": "\u0cb8\u0c82\u0c96\u0ccd\u0caf\u0cc6",
	"Contents": "\u0caa\u0cb0\u0cbf\u0cb5\u0cbf\u0ca1\u0cbf",
	"Italy": "\u0c87\u0c9f\u0cb2\u0cbf",
	"Poland": "\u0caa\u0ccb\u0cb2\u0cc6\u0c82\u0ca1\u0ccd",
	"Portugal": "\u0caa\u0ccb\u0cb0\u0ccd\u0c9a\u0cc1\u0c97\u0cb2\u0ccd",
	"Luxembourg": "\u0cb2\u0c95\u0ccd\u0cb8\u0cc6\u0c82\u0cac\u0cb0\u0ccd\u0c97\u0ccd",
	"Netherlands": "\u0ca8\u0cc6\u0ca6\u0cb0\u0ccd\u0cb2\u0cc6\u0c82\u0ca1\u0ccd",
	"Bavaria": "\u0cac\u0cb5\u0cc7\u0cb0\u0cbf\u0caf\u0cbe",
	"Austria": "\u0c86\u0cb8\u0ccd\u0c9f\u0ccd\u0cb0\u0cbf\u0caf\u0cbe",
	"Switzerland": "\u0cb8\u0ccd\u0cb5\u0cbf\u0c9c\u0cb0\u0ccd\u0cb2\u0cc6\u0c82\u0ca1\u0ccd",
	"Hungary": "\u0cb9\u0c82\u0c97\u0cc6\u0cb0\u0cbf",
	"Germany": "\u0c9c\u0cb0\u0ccd\u0cae\u0ca8\u0cbf",
	"Norway": "\u0ca8\u0cbe\u0cb0\u0ccd\u0cb5\u0cc6",
	"Denmark": "\u0ca1\u0cc6\u0ca8\u0ccd\u0cae\u0cbe\u0cb0\u0ccd\u0c95\u0ccd",
	"Sweden": "\u0cb8\u0ccd\u0cb5\u0cc0\u0ca1\u0ca8\u0ccd",
	"Finland": "\u0cab\u0cbf\u0ca8\u0ccd\u0cb2\u0ccd\u0caf\u0cbe\u0c82\u0ca1\u0ccd",
	"Bulgaria": "\u0cac\u0cb2\u0ccd\u0c97\u0cc7\u0cb0\u0cbf\u0caf\u0cbe",
	"Soviet Union": "\u0cb8\u0ccb\u0cb5\u0cbf\u0caf\u0ca4\u0ccd \u0c92\u0c95\u0ccd\u0c95\u0cc2\u0c9f",
	"Serbia": "\u0cb8\u0cb0\u0ccd\u0cac\u0cbf\u0caf\u0cbe",
	"Romania": "\u0cb0\u0cca\u0cae\u0cbe\u0ca8\u0cbf\u0caf",
	"Greece": "\u0c97\u0ccd\u0cb0\u0cc0\u0cb8\u0ccd",
	"T\u00fcrkiye": "\u0c9f\u0cb0\u0ccd\u0c95\u0cbf",
	"Egypt": "\u0c88\u0c9c\u0cbf\u0caa\u0ccd\u0c9f\u0ccd",
	"%1 Y %2 M": "%1 \u0cb5 %2 \u0ca4\u0cbf\u0c82",
	"%1 Y": "%1 \u0cb5",
	"%1 M": "%1 \u0ca4\u0cbf\u0c82",
	"%1 ms": "%1 \u0cae\u0cbf.\u0cb8\u0cc6",
	"%1 s": "%1 \u0cb8\u0cc6",
	"%1 min": "%1 \u0ca8\u0cbf",
	"%1 hr": "%1 \u0c97\u0c82",
	"%1 d": "%1 \u0ca6\u0cbf",
	"2 days before yesterday, %H:%M": "\u0c85\u0c9a\u0ccd\u0c9a\u0cc6 \u0cae\u0cca\u0ca8\u0ccd\u0ca8\u0cc6, %H:%M",
	"the day before yesterday, %H:%M": "\u0cae\u0cca\u0ca8\u0ccd\u0ca8\u0cc6, %H:%M",
	"yesterday, %H:%M": "\u0ca8\u0cbf\u0ca8\u0ccd\u0ca8\u0cc6, %H:%M",
	"today, %H:%M": "\u0c87\u0c82\u0ca6\u0cc1, %H:%M",
	"tomorrow, %H:%M": "\u0ca8\u0cbe\u0cb3\u0cc6, %H:%M",
	"the day after tomorrow, %H:%M": "\u0ca8\u0cbe\u0ca1\u0cbf\u0ca6\u0ccd\u0ca6\u0cc1, %H:%M",
	"2 days after tomorrow, %H:%M": "\u0c85\u0c9a\u0ccd\u0c9a\u0cc6 \u0ca8\u0cbe\u0ca1\u0cbf\u0ca6\u0ccd\u0ca6\u0cc1, %H:%M",
	"now": "\u0c88\u0c97",
	"several seconds ago": "\u0cb9\u0cb2\u0cb5\u0cc1 \u0cb8\u0cc6\u0c95\u0cc6\u0c82\u0ca1\u0cc1\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"soon": "\u0cb8\u0ca6\u0ccd\u0caf\u0ca6\u0cb2\u0ccd\u0cb2\u0cc7",
	"%1 {{PLURAL:%1|second|seconds}} ago": "%1 \u0cb8\u0cc6\u0c95\u0cc6\u0c82\u0ca1\u0cc1\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 {{PLURAL:%1|second|seconds}} later": "%1 \u0cb8\u0cc6\u0c95\u0cc6\u0c82\u0ca1\u0cc1\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "%1 \u0ca8\u0cbf\u0cae\u0cbf\u0cb7\u0ca6 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 {{PLURAL:%1|minute|minutes}} later": "%1 \u0ca8\u0cbf\u0cae\u0cbf\u0cb7\u0ca6 \u0ca8\u0c82\u0ca4\u0cb0",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1 \u0c97\u0c82\u0c9f\u0cc6\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 \u0c97\u0c82\u0c9f\u0cc6\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 \u0ca6\u0cbf\u0ca8\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 {{PLURAL:%1|day|days}} later": "%1 \u0ca6\u0cbf\u0ca8\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"%1 {{PLURAL:%1|week|weeks}} ago": "%1 \u0cb5\u0cbe\u0cb0\u0c97\u0cb3 \u0cb9\u0cbf\u0c82\u0ca6\u0cc6",
	"%1 {PLURAL:%1|week|weeks}} later": "%1 \u0cb5\u0cbe\u0cb0\u0c97\u0cb3 \u0ca8\u0c82\u0ca4\u0cb0",
	"\u65e5\u672c": "\u0c9c\u0caa\u0cbe\u0ca8\u0ccd",
	"\ud55c\uad6d": "\u0c95\u0cca\u0cb0\u0cbf\u0caf\u0cbe",
	"\u0e44\u0e17\u0e22": "\u0ca5\u0cc8\u0cb2\u0ccd\u0caf\u0cbe\u0c82\u0ca1\u0ccd",
	"India": "\u0cad\u0cbe\u0cb0\u0ca4",
	"Babylon": "\u0cac\u0ccd\u0caf\u0cbe\u0cac\u0cbf\u0cb2\u0cbe\u0ca8\u0ccd",
	"Persia": "\u0caa\u0cb0\u0ccd\u0cb7\u0cbf\u0caf\u0cbe",
	"\u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1": "\u0cae\u0ccd\u0caf\u0cbe\u0cb8\u0cbf\u0ca1\u0cbe\u0ca8\u0ccd",
	"\u03a3\u03b5\u03bb\u03b5\u03c5\u03ba\u03b9\u03b4\u03ce\u03bd": "\u0cb8\u0cc6\u0cb2\u0ccd\u0caf\u0cc2\u0cb8\u0cbf\u0ca6\u0ccd",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "\u0cb8\u0ccd\u0caa\u0cbe\u0cb0\u0ccd\u0c9f\u0cbe",
	"British": "\u0cac\u0ccd\u0cb0\u0cbf\u0c9f\u0cbf\u0cb7\u0ccd",
	"Maya": "\u0cae\u0cbe\u0caf\u0cbe"
},
"kn-IN");
